@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from benedict.serializers.abstract import AbstractSerializer
-
-from urllib.parse import urlencode
-from urllib.parse import parse_qs
-
 import re
+from urllib.parse import parse_qs, urlencode
+
+from benedict.serializers.abstract import AbstractSerializer
 
 
 class QueryStringSerializer(AbstractSerializer):
@@ -14,7 +12,12 @@ class QueryStringSerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(QueryStringSerializer, self).__init__()
+        super(QueryStringSerializer, self).__init__(
+            extensions=[
+                "qs",
+                "querystring",
+            ],
+        )
 
     def decode(self, s, **kwargs):
         flat = kwargs.pop("flat", True)
